# Application to replace qdigidoc v3 and qesteidutil applications
# as the tool for managing estonian ID card and provide
# fully qualified digital signature for users of Estonian ID card.
# Limited support is also available for ID Cards of Latvia and Finland.
#
# Due to https://github.com/open-eid/DigiDoc4-Client/issues/259
# Sources tarball is obtained from VCS to include submodules
# with following instructions:
#
# git clone --recursive https://github.com/open-eid/DigiDoc4-Client/
# cd DigiDoc4-Client
# git checkout v4.0.0
# git submodule update
# cd ..
# mv  DigiDoc4-Client/ DigiDoc4-Client-4.0.0/
# tar zcvf DigiDoc4-Client-4.0.0.tar.gz --exclude-vcs DigiDoc4-Client-4.0.0/
%global upstream_name DigiDoc4-Client

Name:           digidoc4-client
Version:        4.0.0
Release:        3%{?dist}
Summary:        Estonian digital signature and encryption application
License:        LGPLv2+
URL:            https://github.com/open-eid/DigiDoc4-Client
Source0:        %{upstream_name}-%{version}.tar.gz
Patch0:         qtsingleapp.patch
Source1:        EE.xml
Source2:        config.json
Source3:        config.pub
Source4:        config.rsa
Source5:        config.qrc
Source6:        TSL.qrc
Source7:        tl-mp.xml

BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  libdigidocpp-devel
BuildRequires:  openldap-devel
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(libpcsclite) >= 1.7
BuildRequires:  libappstream-glib
BuildRequires:  qtsingleapplication-qt5-devel
Requires:       hicolor-icon-theme
# Dynamically loaded library
Requires:       opensc%{?_isa}
Requires:       pcsc-lite-ccid%{?_isa}
Conflicts:      qdigidoc

%description
DigiDoc4 Client is an application for digitally signing and encrypting
documents; the software includes functionality to manage Estonian ID-card -
change pin codes, update certificates etc.


%package        nautilus
Summary:        Nautilus extension for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       nautilus-python

%description    nautilus
The %{name}-nautilus package contains the %{name} 
extension for the nautilus file manager.

%prep
%setup -q -n %{upstream_name}-%{version}

%patch0 -p1

cp %{S:1} client/
cp %{S:2} common/
cp %{S:3} common/
cp %{S:4} common/
cp %{S:5} common/
cp %{S:6} client/
cp %{S:7} client/

# Remove bundled qtsingleapplication to make sure it isn't used
rm -rf qtsingleapplication

%build
%{cmake} . -DBREAKPAD=FALSE

%make_build

%install
%make_install

desktop-file-validate %{buildroot}/%{_datadir}/applications/qdigidoc4.desktop

%find_lang nautilus-qdigidoc

%files
%doc README.md CONTRIBUTING.md RELEASE-NOTES.md
%license COPING LICENSE.LGPL
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/mime/packages/*.xml
%{_datadir}/icons/hicolor/*/*/*.png
%{_mandir}/man1/qdigidoc4.1*
%{_datadir}/kde4/services/*.desktop

%files nautilus -f nautilus-qdigidoc.lang
%{_datadir}/nautilus-python/extensions/*

%changelog
* Mon Jun 25 2018 Dmitri Smirnov <dmitri@smirnov.ee> - 4.0.0-3
- Add instructions on how to obtain the tarball
- Re-pack the sources tarball with ones obtained from VCS.

* Mon Jun 18 2018 Dmitri Smirnov <dmitri@smirnov.ee> - 4.0.0-2
- Add a patch for sanbox compilation

* Wed Jun 13 2018 Dmitri Smirnov <dmitri@smirnov.ee> - 4.0.0-1
- Update sources to the 4.0.0 release
- Add a patch to workaround the Qt 5.11 compatibility

* Sun Jun 03 2018 Dmitri Smirnov <dmitri@smirnov.ee> - 0.6.0-3
- Update sources to the latest one

* Thu May 03 2018 Dmitri Smirnov <dmitri@smirnov.ee> - 0.6.0-2
- Remove filetype bindings and icons to avoid conflict with DigiDoc3

* Tue May 01 2018 Dmitri Smirnov <dmitri@smirnov.ee> - 0.6.0-1
- Initial packaging of 0.6.0 beta
